@@ -7,4 +7,6 @@ class DistributionImage(CamelModel):
     name: str
     format: str
     file: BytesIO
+    width: int
+    height: int
 
